@@ -10,7 +10,7 @@ from struct import pack # for network byte order
 # third party
 from mongrel2 import handler, request
 
-__version__ = '0.1.2'
+__version__ = '0.1.5'
 
 logger = logging.getLogger(__name__)
 
@@ -82,6 +82,8 @@ class Request(request.Request):
         else:
             self._decode_flags()
 
+        self.query = req.headers.get('QUERY', '')
+
     def _decode_flags(self):
         """
         flags is an 8 bit (1 byte) integer representing the first 8 bits of a websocket frame
@@ -146,6 +148,10 @@ class Request(request.Request):
 
 
 class Connection(handler.Connection):
+
+    request_class = Request
+    """the default request class"""
+
     """A replacement for m2's vanilla Connection class, use this one instead to make
     working with websockets easy-peasy"""
     def __init__(self, sub_addr, pub_addr):
@@ -165,7 +171,7 @@ class Connection(handler.Connection):
             logger.info('{} RECEIVED'.format(m2_req.conn_id))
 
             try:
-                ws_req = Request(m2_req)
+                ws_req = self.request_class(m2_req)
 
                 if ws_req.is_handshake() or ws_req.is_disconnect():
                     # drop these through so they can be handled
@@ -238,11 +244,11 @@ class Connection(handler.Connection):
             }
         )
 
-    def reply_non_websocket(self, req):
-        """handle any non websocket requests, normally, you'll want to just fail it
-        but sometimes it is handy to be able to override this in a child class to
-        handle custom cases (specifically for us, a pingdom check"""
-        return self.reply_invalid(req)
+    def reply_to_http(self, req, *args, **kwargs):
+        """this is a wrapper around reply_http that also closes the connection"""
+        r = self.reply_http(req, *args, **kwargs)
+        self.close(req)
+        return r
 
     def reply_invalid(self, req):
         """reply to a non websocket request on a websocket connection"""
@@ -252,13 +258,18 @@ class Connection(handler.Connection):
             req.headers
         ))
 
-        self.reply_http(
+        self.reply_to_http(
           req,
           body='',
           code=501,
           status='Not Implemented',
         )
-        self.close(req)
+
+    def reply_non_websocket(self, req):
+        """handle any non websocket requests, normally, you'll want to just fail it
+        but sometimes it is handy to be able to override this in a child class to
+        handle custom cases (specifically for us, a pingdom check"""
+        return self.reply_invalid(req)
 
     def reply_to_ping(self, req):
         """reply to a ping request with a pong request"""
